==> drd-8.x-3.0-rc2.tar.gz: drd/src/RemoteActions.php <==
<?php

namespace Drupal\drd;

use Drupal\Core\Form\FormStateInterface;

use Drupal\system\ActionConfigEntityInterface;

/**
 * Class RemoteActions.
 *
 * @package Drupal\drd
 */
class RemoteActions implements RemoteActionsInterface {

  /**
   * @var string
   */
  private $mode;

  /**
   * @var int
   */
  private $count = 0;

  /**
   * @var ActionConfigEntityInterface
   */
  private $action;

  /**
   * An array of actions that can be executed.
   *
   * @var ActionConfigEntityInterface[]
   */
  private $actions = array();

  /**
   * The entity manager.
   *
   * @var \Drupal\Core\Entity\EntityManagerInterface
   */
  protected $entityManager;

  /**
   * The action storage.
   *
   * @var \Drupal\Core\Entity\EntityStorageInterface
   */
  protected $actionStorage;

  /**
   * @var \Drupal\drd\Entity\BaseInterface[]
   */
  protected $entities;

  /**
   * @inheritDoc
   */
  public function __construct() {
    $this->entityManager = \Drupal::entityTypeManager();
    $this->actionStorage = $this->entityManager->getStorage('action');
    $this->setMode('drd');
  }

  /**
   * @inheritDoc
   */
  public function setMode($mode) {
    $this->mode = $mode;
    $this->actions = array_filter($this->actionStorage->loadMultiple(), function (ActionConfigEntityInterface $action) use ($mode) {
      return $action->getType() == $mode;
    });
    return $this;
  }

  /**
   * @inheritDoc
   */
  public function getSelectedAction() {
    return $this->action;
  }

  /**
   * @inheritDoc
   */
  public function getExecutedCount() {
    return $this->count;
  }

  /**
   * @param array $options
   * @return array
   */
  protected function getBulkOptions($options) {
    $bulkOptions = [];
    // Filter the action list.
    foreach ($this->actions as $id => $action) {
      if (!empty($options['selected_actions'])) {
        $in_selected = in_array($id, $options['selected_actions']);
        if (($options['include_exclude'] == 'include') && !$in_selected) {
          continue;
        }
        elseif (($options['include_exclude'] == 'exclude') && $in_selected) {
          continue;
        }
      }

      $bulkOptions[$id] = $action->label();
    }

    asort($bulkOptions);
    return $bulkOptions;
  }

  /**
   * @inheritDoc
   */
  public function buildForm(&$form, FormStateInterface $form_state, $options = []) {
    $form['#type'] = 'container';
    $form['action'] = [
      '#type' => 'select',
      '#title' => t('Action'),
      '#options' => ['' => '-- ' . t('select') . ' --'] + $this->getBulkOptions($options),
    ];
    $form['actions'] = [
      '#type' => 'container',
      '#weight' => 9,
      'submit' => [
        '#type' => 'submit',
        '#value' => t('Apply'),
      ],
    ];


    foreach ($form['action']['#options'] as $action_key => $action_label) {
      if (empty($action_key)) {
        continue;
      }
      $action = $this->actions[$action_key]->getPlugin();
      if ($action instanceof \Drupal\drd\Plugin\Action\BaseConfigurableInterface) {
        $form[$action_key] = [
            '#type' => 'container',
            '#weight' => 8,
            '#states' => [
              'visible' => [
                '#edit-action' => ['value' => $action_key,],
              ],
            ],
          ] + $action->buildConfigurationForm([], $form_state);
      }
    }
  }

  /**
   * @inheritDoc
   */
  public function validateForm(&$form, FormStateInterface $form_state) {
    $action = $this->actions[$form_state->getValue('action')]->getPlugin();
    if ($action instanceof \Drupal\drd\Plugin\Action\BaseConfigurableInterface) {
      $action->validateConfigurationForm($form, $form_state);
    }
  }

  /**
   * @inheritDoc
   */
  public function setSelectedEntities($entities) {
    $this->entities = is_array($entities) ? $entities : [$entities];
    return $this;
  }

  /**
   * @inheritDoc
   */
  public function submitForm(&$form, FormStateInterface $form_state) {
    /** @var ActionConfigEntityInterface $action */
    $this->action = $this->actions[$form_state->getValue('action')];
    /** @var \Drupal\drd\Plugin\Action\BaseEntity $actionPlugin */
    $actionPlugin = $this->action->getPlugin();
    if ($actionPlugin instanceof \Drupal\drd\Plugin\Action\BaseConfigurableInterface) {
      $actionPlugin->submitConfigurationForm($form, $form_state);
    }

    if ($actionPlugin instanceof \Drupal\drd\Plugin\Action\BaseEntityInterface) {
      $permittedEntities = [];
      /** @var \Drupal\drd\Entity\BaseInterface $entity */
      foreach ($this->entities as $entity) {
        // Skip execution if the user did not have access.
        if (!$actionPlugin->access($entity)) {
          drupal_set_message(t('No access to execute %action on the @entity_type_label %entity_label.', [
            '%action' => $action->label(),
            '@entity_type_label' => $entity->getEntityType()->getLabel(),
            '%entity_label' => $entity->label()
          ]), 'error');
          continue;
        }

        $this->count++;
        $permittedEntities[] = $entity;
      }
      \Drupal::service('queue.drd')->createItems($actionPlugin, $permittedEntities);
    }
    else {
      $this->count = 1;
      \Drupal::service('queue.drd')->createItem($actionPlugin);
    }

  }

}

==> drd-8.x-3.4.tar.gz: drd/src/RemoteActions.php <==
<?php

namespace Drupal\drd;

use Drupal\Core\Entity\EntityStorageInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\drd\Entity\BaseInterface;
use Drupal\drd\Plugin\Action\BaseConfigurableInterface;
use Drupal\drd\Plugin\Action\BaseEntity;
use Drupal\drd\Plugin\Action\BaseEntityInterface;
use Drupal\system\ActionConfigEntityInterface;

/**
 * Class RemoteActions.
 *
 * @package Drupal\drd
 */
class RemoteActions implements RemoteActionsInterface {

  /**
   * @var string
   */
  private $mode;

  /**
   * @var int
   */
  private $count = 0;

  /**
   * @var ActionConfigEntityInterface
   */
  private $action;

  /**
   * An array of actions that can be executed.
   *
   * @var ActionConfigEntityInterface[]
   */
  private $actions = array();

  /**
   * The entity manager.
   *
   * @var \Drupal\Core\Entity\EntityManagerInterface
   */
  protected $entityManager;

  /**
   * The action storage.
   *
   * @var EntityStorageInterface
   */
  protected $actionStorage;

  /**
   * @var BaseInterface[]
   */
  protected $entities;

  /**
   * @inheritDoc
   */
  public function __construct() {
    $this->entityManager = \Drupal::entityTypeManager();
    $this->actionStorage = $this->entityManager->getStorage('action');
    $this->setMode('drd');
  }

  /**
   * @inheritDoc
   */
  public function setMode($mode) {
    $this->mode = $mode;
    $this->actions = array_filter($this->actionStorage->loadMultiple(), function (ActionConfigEntityInterface $action) use ($mode) {
      return $action->getType() == $mode;
    });
    return $this;
  }

  /**
   * @inheritDoc
   */
  public function getSelectedAction() {
    return $this->action;
  }

  /**
   * @inheritDoc
   */
  public function getExecutedCount() {
    return $this->count;
  }

  /**
   * @param array $options
   * @return array
   */
  protected function getBulkOptions($options) {
    $bulkOptions = [];
    // Filter the action list.
    foreach ($this->actions as $id => $action) {
      if (!empty($options['selected_actions'])) {
        $in_selected = in_array($id, $options['selected_actions']);
        if (($options['include_exclude'] == 'include') && !$in_selected) {
          continue;
        }
        elseif (($options['include_exclude'] == 'exclude') && $in_selected) {
          continue;
        }
      }

      $bulkOptions[$id] = $action->label();
    }

    asort($bulkOptions);
    return $bulkOptions;
  }

  /**
   * @inheritDoc
   */
  public function buildForm(&$form, FormStateInterface $form_state, $options = []) {
    $form['#type'] = 'container';
    $form['action'] = [
      '#type' => 'select',
      '#title' => t('Action'),
      '#options' => ['' => '-- ' . t('select') . ' --'] + $this->getBulkOptions($options),
    ];
    $form['actions'] = [
      '#type' => 'container',
      '#weight' => 9,
      'submit' => [
        '#type' => 'submit',
        '#value' => t('Apply'),
      ],
    ];


    foreach ($form['action']['#options'] as $action_key => $action_label) {
      if (empty($action_key)) {
        continue;
      }
      $action = $this->actions[$action_key]->getPlugin();
      if ($action instanceof BaseConfigurableInterface) {
        $form[$action_key] = [
            '#type' => 'container',
            '#weight' => 8,
            '#states' => [
              'visible' => [
                '#edit-action' => ['value' => $action_key,],
              ],
            ],
          ] + $action->buildConfigurationForm([], $form_state);
      }
    }
  }

  /**
   * @inheritDoc
   */
  public function validateForm(&$form, FormStateInterface $form_state) {
    $action = $this->actions[$form_state->getValue('action')]->getPlugin();
    if ($action instanceof BaseConfigurableInterface) {
      $action->validateConfigurationForm($form, $form_state);
    }
  }

  /**
   * @inheritDoc
   */
  public function setSelectedEntities($entities) {
    $this->entities = is_array($entities) ? $entities : [$entities];
    return $this;
  }

  /**
   * @inheritDoc
   */
  public function submitForm(&$form, FormStateInterface $form_state) {
    /** @var ActionConfigEntityInterface $action */
    $this->action = $this->actions[$form_state->getValue('action')];
    /** @var BaseEntity $actionPlugin */
    $actionPlugin = $this->action->getPlugin();
    if ($actionPlugin instanceof BaseConfigurableInterface) {
      $actionPlugin->submitConfigurationForm($form, $form_state);
    }

    if ($actionPlugin instanceof BaseEntityInterface) {
      $permittedEntities = [];
      /** @var BaseInterface $entity */
      foreach ($this->entities as $entity) {
        // Skip execution if the user did not have access.
        if (!$actionPlugin->access($entity)) {
          drupal_set_message(t('No access to execute %action on the @entity_type_label %entity_label.', [
            '%action' => $action->label(),
            '@entity_type_label' => $entity->getEntityType()->getLabel(),
            '%entity_label' => $entity->label()
          ]), 'error');
          continue;
        }

        $this->count++;
        $permittedEntities[] = $entity;
      }
      \Drupal::service('queue.drd')->createItems($actionPlugin, $permittedEntities);
    }
    else {
      $this->count = 1;
      \Drupal::service('queue.drd')->createItem($actionPlugin);
    }

  }

}
